/* To be inserted in other files to bypass the chksrc tests */
/* NOCHKSRC */


#line 3 "lex.CQL_.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer CQL__create_buffer
#define yy_delete_buffer CQL__delete_buffer
#define yy_flex_debug CQL__flex_debug
#define yy_init_buffer CQL__init_buffer
#define yy_flush_buffer CQL__flush_buffer
#define yy_load_buffer_state CQL__load_buffer_state
#define yy_switch_to_buffer CQL__switch_to_buffer
#define yyin CQL_in
#define yyleng CQL_leng
#define yylex CQL_lex
#define yylineno CQL_lineno
#define yyout CQL_out
#define yyrestart CQL_restart
#define yytext CQL_text
#define yywrap CQL_wrap
#define yyalloc CQL_alloc
#define yyrealloc CQL_realloc
#define yyfree CQL_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 34
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types.
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t;
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE CQL_restart(CQL_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int CQL_leng;

extern FILE *CQL_in, *CQL_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)

/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up CQL_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up CQL_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 * Given that the standard has decreed that size_t exists since 1989,
 * I guess we can afford to depend on it. Manoj.
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via CQL_restart()), so that the user can continue scanning by
	 * just pointing CQL_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when CQL_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int CQL_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow CQL_wrap()'s to do buffer switches
 * instead of setting up a fresh CQL_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void CQL_restart (FILE *input_file  );
void CQL__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE CQL__create_buffer (FILE *file,int size  );
void CQL__delete_buffer (YY_BUFFER_STATE b  );
void CQL__flush_buffer (YY_BUFFER_STATE b  );
void CQL_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void CQL_pop_buffer_state (void );

static void CQL_ensure_buffer_stack (void );
static void CQL__load_buffer_state (void );
static void CQL__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER CQL__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE CQL__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE CQL__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE CQL__scan_bytes (yyconst char *bytes,int len  );

void *CQL_alloc (yy_size_t  );
void *CQL_realloc (void *,yy_size_t  );
void CQL_free (void *  );

#define yy_new_buffer CQL__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        CQL_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            CQL__create_buffer(CQL_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        CQL_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            CQL__create_buffer(CQL_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *CQL_in = (FILE *) 0, *CQL_out = (FILE *) 0;

typedef int yy_state_type;

extern int CQL_lineno;

int CQL_lineno = 1;

extern char *CQL_text;
#define yytext_ptr CQL_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up CQL_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	CQL_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 59
#define YY_END_OF_BUFFER 60
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[170] =
    {   0,
        0,    0,   60,   58,   56,   57,   41,   58,   45,   46,
       35,   37,   39,   38,   42,   36,   30,   30,   30,   52,
       49,   54,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   43,   44,   48,   58,   56,
        0,   34,   33,    0,    0,    0,   30,   30,   30,    0,
        0,   29,   29,   40,   32,   32,   30,   28,    0,   51,
       50,   53,   55,    0,   55,    5,    7,   55,   55,   55,
       55,   55,   55,   12,   13,   55,   55,   55,   23,   55,
       55,   55,   55,   47,    0,    0,   34,   31,    0,    0,
       27,    0,   29,   29,    0,   32,    0,   26,    0,   22,

        4,    6,   55,   55,   55,   55,   55,   55,   14,   55,
       21,   55,   55,   55,   55,   55,   55,    0,   25,    0,
       32,    0,    0,   32,   26,   24,    8,   55,   55,   55,
       55,    2,   15,   20,   55,   55,   55,   18,   55,    0,
       31,   25,    0,   32,    0,   24,    0,   55,   10,   19,
       11,   16,   55,   55,    3,    0,    0,   24,   55,   55,
        1,    0,   24,   55,   55,    9,   55,   17,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    4,    1,    1,    1,    5,    6,
        7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
       16,   16,   16,   16,   16,   16,   16,   17,    1,   18,
       19,   20,    1,    1,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   27,   30,   31,   32,   33,   34,   27,
       27,   35,   36,   37,   38,   39,   40,   41,   42,   27,
       43,   44,   45,    1,   46,    1,   21,   22,   23,   24,

       25,   26,   27,   28,   29,   27,   30,   31,   32,   33,
       34,   27,   27,   35,   36,   37,   38,   39,   40,   41,
       42,   27,    1,   47,    1,    1,    1,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,

       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27
    } ;

static yyconst flex_int32_t yy_meta[48] =
    {   0,
        1,    1,    2,    3,    4,    5,    5,    1,    1,    1,
        1,    1,    1,    6,    6,    6,    7,    1,    1,    1,
        8,    8,    8,    8,    8,    8,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    3,    1,    1,    9,    1
    } ;

static yyconst flex_int16_t yy_base[182] =
    {   0,
        0,    0,  438,  439,  435,  439,  439,   45,  439,  439,
      439,   41,  439,   46,   51,  439,   56,   61,   70,   60,
      439,  417,   57,   52,  418,   70,   42,   71,   74,   79,
       81,   85,   84,   86,   94,  439,  439,  417,  386,  430,
      111,   99,  439,  421,  120,  112,  117,  122,  133,  126,
      138,  147,  156,  439,  151,  159,  166,  439,    0,  439,
      439,  439,  398,  394,  166,  107,  392,  160,  168,  169,
      170,  172,  175,  391,  174,  176,  180,  181,  186,  182,
      183,  118,  188,  439,  107,  197,  439,  206,  211,  220,
      439,    0,  228,  233,  242,  214,  250,    0,    0,  388,

      383,  380,  201,  235,  220,  237,  243,   32,  377,  221,
      370,  245,  246,  251,  250,  252,  253,  275,    0,  267,
      278,  286,  289,  292,    0,  270,  362,  270,  268,  292,
      261,  343,  341,  340,  279,  294,  295,  337,  298,  305,
      310,    0,  313,  317,  348,  312,  307,  305,  334,  333,
      330,  329,  317,  319,  328,  339,  171,  170,  318,  320,
      194,  152,  141,  322,  323,   96,  325,   37,  439,  361,
      365,  374,  383,  387,  390,  393,  394,  398,  404,  413,
      422
    } ;

static yyconst flex_int16_t yy_def[182] =
    {   0,
      169,    1,  169,  169,  169,  169,  169,  170,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  169,  169,  171,  169,  169,
      170,  172,  169,  173,  173,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  174,  169,
      169,  169,  171,  169,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  169,  172,  169,  169,  169,  169,  169,
      169,  175,  169,  169,  169,  169,  169,  176,  177,  171,

      171,  171,  171,  171,  171,  171,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  169,  178,  169,
      169,  169,  169,  169,  176,  179,  171,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  171,  171,  169,
      169,  178,  169,  169,  169,  179,  180,  171,  171,  171,
      171,  171,  171,  171,  171,  181,  180,  180,  171,  171,
      171,  181,  181,  171,  171,  171,  171,  171,    0,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169
    } ;

static yyconst flex_int16_t yy_nxt[487] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,    4,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   25,   25,   29,   25,
       30,   25,   31,   32,   25,   33,   34,   25,   25,   35,
       25,   25,   36,    4,   37,   38,   39,   42,   64,   43,
       44,   44,   46,   64,   47,   48,   49,   50,   64,   51,
       52,   53,   54,  132,   55,   55,   55,   56,   64,   57,
       57,   49,   56,   64,   57,   57,   49,   58,   60,   61,
       70,   56,   58,   49,   49,   49,   64,   64,   45,   65,
       64,   71,   66,   67,   68,   64,   59,   64,   69,   72,

       64,   64,   64,   43,   80,   73,   74,   76,   81,   75,
       64,   43,   64,   42,   77,   43,   44,   44,   78,   79,
       82,   83,   87,   64,   85,   55,   55,   55,   56,  102,
       57,   57,   49,   56,   64,   57,   57,   49,   58,   88,
       88,   88,   86,   58,   56,  163,   49,   49,   49,   50,
       86,   89,   89,   90,   45,  116,  163,   59,   50,   91,
       93,   93,   94,   41,   55,   55,   55,   50,   91,   94,
       94,   94,   96,   96,   96,   95,   64,   56,   92,   57,
       57,   49,   64,   97,   64,   64,   64,   58,   64,  100,
       64,   64,   64,  105,  109,  103,   64,   64,   64,   64,

      106,   85,   64,  104,   64,  110,  107,  101,  108,  113,
       64,  112,  117,  115,  158,  158,  111,   64,  114,   88,
       88,   88,   50,  127,   89,   89,   90,   96,   96,   96,
      118,   50,   91,   90,   90,   90,   64,   64,  122,   50,
       85,   93,   93,   94,   50,  133,   94,   94,   94,   91,
      120,   64,  120,   64,  129,  121,  121,  121,  123,   64,
      123,   64,   64,  124,  124,  124,   64,   64,   64,   64,
      135,  128,  130,  145,  137,  134,  138,   64,  131,  136,
      121,  121,  121,  140,   64,  140,   64,  139,  141,  141,
      141,  121,  121,  121,  143,   64,  143,  151,  148,  144,

      144,  144,  124,  124,  124,  124,  124,  124,   64,  149,
       64,   64,  147,  152,   64,  145,  150,  154,  141,  141,
      141,   64,  155,  141,  141,  141,  144,  144,  144,  153,
      144,  144,  144,   64,   64,   64,   64,  159,   64,   64,
      164,   64,  160,  163,   64,   64,   64,  167,  165,   64,
       64,  158,  156,   64,  147,  161,   64,   64,  166,   64,
      168,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       63,   63,   63,   63,   85,   85,   85,   85,   64,   85,
       85,   85,   85,   44,   44,   44,   64,   44,   44,   44,
       44,   44,   98,   64,   98,  119,   64,  119,  125,   64,

      125,  126,  126,  142,   64,  142,  146,   64,   64,  146,
       99,  146,  146,  157,   64,  157,  157,  157,  157,  157,
      157,  157,  162,   87,  162,  162,  162,  162,  162,  162,
      162,   40,   84,   64,   64,   62,   40,  169,    3,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169
    } ;

static yyconst flex_int16_t yy_chk[487] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    8,  108,    8,
        8,    8,   12,  168,   12,   12,   12,   14,   27,   14,
       14,   14,   15,  108,   15,   15,   15,   17,   24,   17,
       17,   17,   18,   23,   18,   18,   18,   17,   20,   20,
       27,   19,   18,   19,   19,   19,   26,   28,    8,   23,
       29,   28,   23,   24,   26,   30,   17,   31,   26,   28,

       33,   32,   34,   42,   33,   28,   29,   30,   33,   29,
       35,   85,  166,   41,   31,   41,   41,   41,   31,   32,
       34,   35,   45,   66,   45,   46,   46,   46,   47,   66,
       47,   47,   47,   48,   82,   48,   48,   48,   47,   50,
       50,   50,   42,   48,   49,  163,   49,   49,   49,   51,
       85,   51,   51,   51,   41,   82,  162,   47,   52,   51,
       52,   52,   52,   45,   55,   55,   55,   53,   52,   53,
       53,   53,   56,   56,   56,   55,   68,   57,   51,   57,
       57,   57,   65,   56,   69,   70,   71,   57,   72,   65,
       75,   73,   76,   70,   75,   68,   77,   78,   80,   81,

       71,   86,   79,   69,   83,   76,   72,   65,   73,   79,
      161,   78,   83,   81,  158,  157,   77,  103,   80,   88,
       88,   88,   89,  103,   89,   89,   89,   96,   96,   96,
       88,   90,   89,   90,   90,   90,  105,  110,   96,   93,
       86,   93,   93,   93,   94,  110,   94,   94,   94,   93,
       95,  104,   95,  106,  105,   95,   95,   95,   97,  107,
       97,  112,  113,   97,   97,   97,  115,  114,  116,  117,
      113,  104,  106,  126,  115,  112,  116,  131,  107,  114,
      120,  120,  120,  118,  129,  118,  128,  117,  118,  118,
      118,  121,  121,  121,  122,  135,  122,  131,  128,  122,

      122,  122,  123,  123,  123,  124,  124,  124,  130,  129,
      136,  137,  126,  135,  139,  146,  130,  137,  140,  140,
      140,  148,  139,  141,  141,  141,  143,  143,  143,  136,
      144,  144,  144,  153,  159,  154,  160,  148,  164,  165,
      159,  167,  153,  156,  155,  152,  151,  165,  160,  150,
      149,  147,  145,  138,  146,  154,  134,  133,  164,  132,
      167,  170,  170,  170,  170,  170,  170,  170,  170,  170,
      171,  171,  171,  171,  172,  172,  172,  172,  127,  172,
      172,  172,  172,  173,  173,  173,  111,  173,  173,  173,
      173,  173,  174,  109,  174,  175,  102,  175,  176,  101,

      176,  177,  177,  178,  100,  178,  179,   74,   67,  179,
       64,  179,  179,  180,   63,  180,  180,  180,  180,  180,
      180,  180,  181,   44,  181,  181,  181,  181,  181,  181,
      181,   40,   39,   38,   25,   22,    5,    3,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int CQL__flex_debug;
int CQL__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *CQL_text;
#line 1 "CQL.l"
/*
//%LICENSE////////////////////////////////////////////////////////////////
//
// Licensed to The Open Group (TOG) under one or more contributor license
// agreements.  Refer to the OpenPegasusNOTICE.txt file distributed with
// this work for additional information regarding copyright ownership.
// Each contributor licenses this file to you under the OpenPegasus Open
// Source License; you may not use this file except in compliance with the
// License.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//////////////////////////////////////////////////////////////////////////
*/
/*
   This file describes the language tokens possible for CQL. When a token is
   matched, the token postion is updated in the CQL_globalParserState, copying
   from the lex buffer  to a shared buffer (shared with the lexer and parser)
   may happen, then a token identifier is returned to the parser.

*/
#line 42 "CQL.l"
extern int CQLInput(char* buffer, int& numRead, int numRequested);
extern int CQL_error(const char*);

#ifdef CQLINPUT
#define YY_INPUT(BUF, NREAD, NREQUESTED) CQLInput(BUF, NREAD, NREQUESTED)
#endif

#include <Pegasus/Common/Config.h>
#include <Pegasus/Common/CommonUTF.h>
#include <Pegasus/Common/MessageLoader.h>
#include "CQLParserState.h"
#include <stdlib.h>
#include <stdio.h>
#include <cstring>
#include "CQLObjects.h"
#include "CQLYACC.h"
PEGASUS_NAMESPACE_BEGIN

extern CQLParserState* CQL_globalParserState;

PEGASUS_NAMESPACE_END


#ifdef CQL_DEBUG_LEXER
#define CQL_DEBUG_TRACE(X) \
    printf(X);
#define CQL_DEBUG_TRACE2(X,Y) \
    printf(X,Y);
#else
#define CQL_DEBUG_TRACE(X)
#define CQL_DEBUG_TRACE2(X,Y)
#endif

/* Avoid warn_unused_result warnings in Linux RPM build */
#ifndef ECHO
# define ECHO do { size_t ignored = fwrite(CQL_text, CQL_leng, 1, CQL_out); } while(0)
#endif

int lineno;

#line 716 "lex.CQL_.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int CQL_wrap (void );
#else
extern int CQL_wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( CQL_text, CQL_leng, 1, CQL_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( CQL_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( CQL_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, CQL_in))==0 && ferror(CQL_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(CQL_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int CQL_lex (void);

#define YY_DECL int CQL_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after CQL_text and CQL_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;

#line 122 "CQL.l"


#line 872 "lex.CQL_.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! CQL_in )
			CQL_in = stdin;

		if ( ! CQL_out )
			CQL_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			CQL_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				CQL__create_buffer(CQL_in,YY_BUF_SIZE );
		}

		CQL__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of CQL_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 170 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 169 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 124 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_SELECT] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_SELECT;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 132 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_FROM] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_FROM;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 140 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_WHERE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_WHERE;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 148 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_ANY] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_ANY;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 156 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_AS] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_AS;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 163 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_ASC] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_ASC;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 170 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_BY] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_BY;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 177 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_DESC] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_DESC;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 185 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_DISTINCT] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_DISTINCT;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 192 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_EVERY] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_EVERY;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 199 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_FIRST] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_FIRST;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 206 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_IN] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_IN;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 213 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_IS] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_IS;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 220 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [ISA] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_ISA;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 227 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOKE_LIKE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_LIKE;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 234 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_ORDER] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_ORDER;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 241 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_SATISFIES] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_SATISFIES;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 248 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_TRUE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_TRUE;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 255 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_FALSE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_FALSE;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 262 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_NULL] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_NULL;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 269 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_NOT] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_NOT;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 276 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_AND] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_AND;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 283 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_OR] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_OR;
}
	YY_BREAK
/* NOCHKSRC */
case 24:
YY_RULE_SETUP
#line 290 "CQL.l"
{
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
     /* remove any single quotes surrounding embedded literals */
     size_t n;
     if(CQL_lval.strValue)
             delete [] CQL_lval.strValue;
     /* CHKSRC */
    // chuck
    if (!isUTF8Str(CQL_text))
    {
        CQL_DEBUG_TRACE("LEX: [STRING]-> BAD UTF\n");
        throw CQLSyntaxErrorException(
            MessageLoaderParms("CQL.CQL_y.BAD_UTF8",
            "Bad UTF8 encountered parsing rule $0 in position $1.",
            "identifier",
            CQL_globalParserState->currentTokenPos));
    }

     String s(CQL_text);
     Uint32 index = s.find("'");
     if(index != PEG_NOT_FOUND){
        s.remove(index,1);
        s.remove(s.size()-1,1);
        CString cstr = s.getCString();
        const char* string = (const char*)cstr;
        n = strlen(string);
        CQL_lval.strValue = new char[n+1];
        memcpy(CQL_lval.strValue, string, n);
     }else{
        n = strlen(CQL_text);
        CQL_lval.strValue = new char[n+1];
      memcpy(CQL_lval.strValue, CQL_text, n);
     }
    CQL_lval.strValue[n] = '\0';
    CQL_DEBUG_TRACE2("LEX: %s [SCOPED_PROPERTY] ", CQL_lval.strValue);

    return TOK_SCOPED_PROPERTY;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 330 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_NEGATIVE_HEXADECIMAL] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    /* copy the hex value */
    {
        size_t n = strlen(CQL_text);
    if(CQL_lval.strValue)
        delete [] CQL_lval.strValue;
        CQL_lval.strValue = new char[n + 1];
        memcpy(CQL_lval.strValue, CQL_text, n);
        CQL_lval.strValue[n] = '\0';
    }
    return TOK_NEGATIVE_HEXADECIMAL;
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 346 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_HEXADECIMAL] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    /* copy the hex value */
    {
        size_t n = strlen(CQL_text);
        if(CQL_lval.strValue)
                delete [] CQL_lval.strValue;
        CQL_lval.strValue = new char[n + 1];
        memcpy(CQL_lval.strValue, CQL_text, n);
        CQL_lval.strValue[n] = '\0';
    }
    return TOK_HEXADECIMAL;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 362 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_NEGATIVE_BINARY] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    /* copy the bin value */
    {
        size_t n = strlen(CQL_text);
    if(CQL_lval.strValue)
                delete [] CQL_lval.strValue;
        CQL_lval.strValue = new char[n + 1];
        memcpy(CQL_lval.strValue, CQL_text, n);
        CQL_lval.strValue[n] = '\0';
    }
    return TOK_NEGATIVE_BINARY;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 378 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_BINARY] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    /* copy the bin value */
    {
        size_t n = strlen(CQL_text);
        if(CQL_lval.strValue)
                delete [] CQL_lval.strValue;
        CQL_lval.strValue = new char[n + 1];
        memcpy(CQL_lval.strValue, CQL_text, n);
        CQL_lval.strValue[n] = '\0';
    }
    return TOK_BINARY;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 395 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_NEGATIVE_INTEGER] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    size_t n = strlen(CQL_text);
    if(CQL_lval.strValue)
        delete [] CQL_lval.strValue;
    CQL_lval.strValue = new char[n + 1];
    memcpy(CQL_lval.strValue, CQL_text, n);
    CQL_lval.strValue[n] = '\0';

    /*CQL_lval.intValue = strtol(CQL_text, (char**)0, 10);*/
    return TOK_NEGATIVE_INTEGER;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 411 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_INTEGER] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    size_t n = strlen(CQL_text);
    if(CQL_lval.strValue)
            delete [] CQL_lval.strValue;
    CQL_lval.strValue = new char[n + 1];
    memcpy(CQL_lval.strValue, CQL_text, n);
    CQL_lval.strValue[n] = '\0';

    /*CQL_lval.intValue = strtol(CQL_text, (char**)0, 10);*/
    return TOK_INTEGER;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 427 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_NEGATIVE_REAL] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    size_t n = strlen(CQL_text);
    if(CQL_lval.strValue)
            delete [] CQL_lval.strValue;
    CQL_lval.strValue = new char[n + 1];
    memcpy(CQL_lval.strValue, CQL_text, n);
    CQL_lval.strValue[n] = '\0';

    /*CQL_lval.realValue = strtod((char*)CQL_text, (char**)0);*/
    return TOK_NEGATIVE_REAL;
}
	YY_BREAK
/* NOCHKSRC */
case 32:
YY_RULE_SETUP
#line 443 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_REAL] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    size_t n = strlen(CQL_text);
    if(CQL_lval.strValue)
            delete [] CQL_lval.strValue;
    CQL_lval.strValue = new char[n + 1];
    memcpy(CQL_lval.strValue, CQL_text, n);
    CQL_lval.strValue[n] = '\0';

    /*CQL_lval.realValue = strtod((char*)CQL_text, (char**)0);*/
    return TOK_REAL;
}
	YY_BREAK
/* CHKSRC */
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 458 "CQL.l"
{
    /* \'[^\'\n]*\' */
    /* ATTN-B: handle long literals by using yyinput(). */
    /* ATTN-B: Handle expansion of special characters */

    CQL_DEBUG_TRACE2("LEX: %s [TOK_STRING_LITERAL] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    /* remove any escaped \ OR escaped ' */

    String _esc_doubleslash = "\\\\";
    String _esc_singlequote = "\\'";

    if (!isUTF8Str(CQL_text))
    {
        CQL_DEBUG_TRACE("LEX: [STRING]-> BAD UTF\n");
        throw CQLSyntaxErrorException(
            MessageLoaderParms("CQL.CQL_y.BAD_UTF8",
                "Bad UTF8 encountered parsing rule $0 in position $1.",
                "literal_string",
                CQL_globalParserState->currentTokenPos));
    }

    String s(CQL_text);

    Uint32 index = 1;
    while((index = s.find(_esc_doubleslash)) != PEG_NOT_FOUND ||
           (index = s.find(_esc_singlequote)) != PEG_NOT_FOUND)
     {
         // make sure we don't remove the slasy from say 'abc\'
         if(index == s.size() - 2)
                break;
         s.remove(index,1);
    }
    CString cstr = s.getCString();
    const char* string = (const char*)cstr;

    /* Copy the string (but remove the surrounding quotes */

    {
    size_t n = strlen(string) - 2;
    if(CQL_lval.strValue)
        delete [] CQL_lval.strValue;
    CQL_lval.strValue = new char[n + 1];
    memcpy(CQL_lval.strValue, string + 1, n);
    CQL_lval.strValue[n] = '\0';
    }
    return TOK_STRING_LITERAL;
}
	YY_BREAK
case 34:
*yy_cp = (yy_hold_char); /* undo effects of setting up CQL_text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up CQL_text again */
YY_RULE_SETUP
#line 508 "CQL.l"
{

    CQL_DEBUG_TRACE("Unterminated string");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 515 "CQL.l"
{
   CQL_DEBUG_TRACE("LEX: [TOK_STAR] ");
   CQL_globalParserState->currentTokenPos+=CQL_leng;
   CQL_globalParserState->tokenCount++;
   return TOK_STAR;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 522 "CQL.l"
{
   CQL_DEBUG_TRACE("LEX: [TOK_DIV] ");
   CQL_globalParserState->currentTokenPos+=CQL_leng;
   CQL_globalParserState->tokenCount++;
   return TOK_DIV;
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 529 "CQL.l"
{
   CQL_DEBUG_TRACE("LEX: [TOK_PLUS] ");
   CQL_globalParserState->currentTokenPos+=CQL_leng;
   CQL_globalParserState->tokenCount++;
   return TOK_PLUS;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 536 "CQL.l"
{
   CQL_DEBUG_TRACE("LEX: [TOK_MINUS] ");
   CQL_globalParserState->currentTokenPos+=CQL_leng;
   CQL_globalParserState->tokenCount++;
   return TOK_MINUS;
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 543 "CQL.l"
{
   CQL_DEBUG_TRACE("LEX: [TOK_COMMA] ");
   CQL_globalParserState->currentTokenPos+=CQL_leng;
   CQL_globalParserState->tokenCount++;
   return TOK_COMMA;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 550 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_DOTDOT] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_DOTDOT;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 557 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_HASH] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_HASH;
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 564 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_DOT] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_DOT;
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 571 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_LBRKT] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_LBRKT;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 578 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_RBRKT] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_RBRKT;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 585 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_LPAR] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_LPAR;
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 592 "CQL.l"
{
    CQL_DEBUG_TRACE("LEX: [TOK_RPAR] ");
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_RPAR;
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 599 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_DBL_PIPE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_DBL_PIPE;
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 606 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_UNDERSCORE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_UNDERSCORE;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 613 "CQL.l"
{
    CQL_DEBUG_TRACE2("LEX: %s [TOK_EQ] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_EQ;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 621 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_NE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_NE;
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 630 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_LE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_LE;
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 638 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_LT] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_LT;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 646 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_GE] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_GE;
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 654 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_GT] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    return TOK_GT;
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 662 "CQL.l"
{

    CQL_DEBUG_TRACE2("LEX: %s [TOK_IDENTIFIER] ", CQL_text);
    CQL_globalParserState->currentTokenPos+=CQL_leng;
    CQL_globalParserState->tokenCount++;
    {
        size_t n = strlen(CQL_text);
        if(CQL_lval.strValue)
            delete [] CQL_lval.strValue;
        CQL_lval.strValue = new char[n + 1];
        memcpy(CQL_lval.strValue, CQL_text, n);
        CQL_lval.strValue[n] = '\0';
    }

    return TOK_IDENTIFIER;
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 679 "CQL.l"
{

    /* Ignore blanks */
    CQL_globalParserState->currentTokenPos+=CQL_leng;
}
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 685 "CQL.l"
{
    CQL_globalParserState->currentTokenPos=0;
    return 0;
   }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 690 "CQL.l"
{
             return 0;
        }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 694 "CQL.l"
{
    delete [] CQL_lval.strValue;
    CQL_lval.strValue = 0;
    CQL_DEBUG_TRACE("LEX::TOK_UNEXPECTED_CHAR\n");

    return TOK_UNEXPECTED_CHAR;
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 702 "CQL.l"
ECHO;
	YY_BREAK
#line 1714 "lex.CQL_.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed CQL_in at a new source and called
			 * CQL_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = CQL_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( CQL_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * CQL_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of CQL_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					CQL_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			CQL_restart(CQL_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) CQL_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;

	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 170 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 170 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 169);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;

    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up CQL_text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;

	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					CQL_restart(CQL_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( CQL_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve CQL_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 *
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void CQL_restart  (FILE * input_file )
{

	if ( ! YY_CURRENT_BUFFER ){
        CQL_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            CQL__create_buffer(CQL_in,YY_BUF_SIZE );
	}

	CQL__init_buffer(YY_CURRENT_BUFFER,input_file );
	CQL__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 *
 */
    void CQL__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		CQL_pop_buffer_state();
	 *		CQL_push_buffer_state(new_buffer);
     */
	CQL_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	CQL__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (CQL_wrap()) processing, but the only time this flag
	 * is looked at is after CQL_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void CQL__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	CQL_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 *
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE CQL__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;

	b = (YY_BUFFER_STATE) CQL_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in CQL__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) CQL_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in CQL__create_buffer()" );

	b->yy_is_our_buffer = 1;

	CQL__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with CQL__create_buffer()
 *
 */
    void CQL__delete_buffer (YY_BUFFER_STATE  b )
{

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		CQL_free((void *) b->yy_ch_buf  );

	CQL_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a CQL_restart() or at EOF.
 */
    static void CQL__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;

	CQL__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then CQL__init_buffer was _probably_
     * called from CQL_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;

	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 *
 */
    void CQL__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		CQL__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *
 */
void CQL_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	CQL_ensure_buffer_stack();

	/* This block is copied from CQL__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from CQL__switch_to_buffer. */
	CQL__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *
 */
void CQL_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	CQL__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		CQL__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void CQL_ensure_buffer_stack (void)
{
	int num_to_alloc;

	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)CQL_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in CQL_ensure_buffer_stack()" );
								
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)CQL_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in CQL_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 *
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE CQL__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;

	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) CQL_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in CQL__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	CQL__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to CQL_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 *
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       CQL__scan_bytes() instead.
 */
YY_BUFFER_STATE CQL__scan_string (yyconst char * yystr )
{

	return CQL__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to CQL_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 *
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE CQL__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;

	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) CQL_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in CQL__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = CQL__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in CQL__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up CQL_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		CQL_text[CQL_leng] = (yy_hold_char); \
		(yy_c_buf_p) = CQL_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		CQL_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 *
 */
int CQL_get_lineno  (void)
{

    return CQL_lineno;
}

/** Get the input stream.
 *
 */
FILE *CQL_get_in  (void)
{
        return CQL_in;
}

/** Get the output stream.
 *
 */
FILE *CQL_get_out  (void)
{
        return CQL_out;
}

/** Get the length of the current token.
 *
 */
int CQL_get_leng  (void)
{
        return CQL_leng;
}

/** Get the current token.
 *
 */

char *CQL_get_text  (void)
{
        return CQL_text;
}

/** Set the current line number.
 * @param line_number
 *
 */
void CQL_set_lineno (int  line_number )
{

    CQL_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 *
 * @see CQL__switch_to_buffer
 */
void CQL_set_in (FILE *  in_str )
{
        CQL_in = in_str ;
}

void CQL_set_out (FILE *  out_str )
{
        CQL_out = out_str ;
}

int CQL_get_debug  (void)
{
        return CQL__flex_debug;
}

void CQL_set_debug (int  bdebug )
{
        CQL__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from CQL_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    CQL_in = stdin;
    CQL_out = stdout;
#else
    CQL_in = (FILE *) 0;
    CQL_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * CQL_lex_init()
     */
    return 0;
}

/* CQL_lex_destroy is for both reentrant and non-reentrant scanners. */
int CQL_lex_destroy  (void)
{

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		CQL__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		CQL_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	CQL_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * CQL_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *CQL_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *CQL_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void CQL_free (void * ptr )
{
	free( (char *) ptr );	/* see CQL_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 702 "CQL.l"


extern "C" int CQL_wrap()
{
    return 1;
}



